From 7a7cc4a60ada79199542faeeba33b017efff0f23 Mon Sep 17 00:00:00 2001
From: Pankaj Yadav <pk@videolan.org>
Date: Tue, 18 Jan 2011 02:11:32 +0530
Subject: [PATCH 5/5] main routine for Symbian

---
 bin/vlc.c |   40 ++++++++++++++++++++++++++++++++--------
 1 files changed, 32 insertions(+), 8 deletions(-)

diff --git a/bin/vlc.c b/bin/vlc.c
index 70eeed0..52987e0 100644
--- a/bin/vlc.c
+++ b/bin/vlc.c
@@ -48,6 +48,19 @@ extern void LocaleFree (const char *);
 extern char *FromLocale (const char *);
 extern void vlc_enable_override (void);
 
+#ifdef __SYMBIAN32__
+
+#include <vlc_common.h>
+vlc_sem_t exit_sem;
+static symbian_libvlc_Wait( libvlc_int_t *p_libvlc )
+{
+    vlc_sem_init(&exit_sem,0);
+    vlc_sem_wait(&exit_sem);
+    vlc_sem_destroy(&exit_sem);
+}
+
+#endif
+
 #ifdef HAVE_MAEMO
 static void dummy_handler (int signum)
 {
@@ -55,6 +68,7 @@ static void dummy_handler (int signum)
 }
 #endif
 
+#ifndef __SYMBIAN32__
 static bool signal_ignored (int signum)
 {
     struct sigaction sa;
@@ -65,17 +79,22 @@ static bool signal_ignored (int signum)
             ? (void *)sa.sa_sigaction : (void *)sa.sa_handler) == SIG_IGN;
 }
 
+static void exit_timeout (int signum)
+{
+    (void) signum;
+    signal (SIGINT, SIG_DFL);
+}
+#endif
+
 static void vlc_kill (void *data)
 {
+#ifndef __SYMBIAN32__
     pthread_t *ps = data;
 
     pthread_kill (*ps, SIGTERM);
-}
-
-static void exit_timeout (int signum)
-{
-    (void) signum;
-    signal (SIGINT, SIG_DFL);
+#else
+    vlc_sem_post(&exit_sem);
+#endif
 }
 
 /*****************************************************************************
@@ -83,6 +102,7 @@ static void exit_timeout (int signum)
  *****************************************************************************/
 int main( int i_argc, const char *ppsz_argv[] )
 {
+#ifndef __SYMBIAN32__
     /* The so-called POSIX-compliant MacOS X reportedly processes SIGPIPE even
      * if it is blocked in all thread. Also some libraries want SIGPIPE blocked
      * as they have no clue about signal masks.
@@ -167,7 +187,7 @@ int main( int i_argc, const char *ppsz_argv[] )
 #endif
     /* Block all these signals */
     pthread_sigmask (SIG_BLOCK, &set, NULL);
-
+#endif
     /* Note that FromLocale() can be used before libvlc is initialized */
     const char *argv[i_argc + 4];
     int argc = 0;
@@ -204,7 +224,7 @@ int main( int i_argc, const char *ppsz_argv[] )
 
     libvlc_set_user_agent (vlc, "VLC media player", "VLC/"PACKAGE_VERSION);
 
-#if !defined (HAVE_MAEMO) && !defined __APPLE__
+#if !defined (HAVE_MAEMO) && !defined (__APPLE__) && !defined(__SYMBIAN32__)
     libvlc_add_intf (vlc, "globalhotkeys,none");
 #endif
     if (libvlc_add_intf (vlc, NULL))
@@ -216,6 +236,7 @@ int main( int i_argc, const char *ppsz_argv[] )
     pthread_t self = pthread_self ();
     libvlc_set_exit_handler (vlc, vlc_kill, &self);
 
+#ifndef __SYMBIAN32__
     if (signal_ignored (SIGHUP)) /* <- needed to handle nohup properly */
         sigdelset (&set, SIGHUP);
     sigdelset (&set, SIGPIPE);
@@ -233,6 +254,9 @@ int main( int i_argc, const char *ppsz_argv[] )
     signal (SIGALRM, exit_timeout);
     pthread_sigmask (SIG_UNBLOCK, &set, NULL);
     alarm (3);
+#else
+    symbian_libvlc_Wait((libvlc_int_t*)vlc);
+#endif
 
     /* Cleanup */
 out:
-- 
1.7.1

